@@ -11,7 +11,8 @@ Example of commandor usage
 :github: http://github.com/Lispython/commandor
 """
 
-from optparse import OptionParser
+from optparse import OptionParser, Option
+
 
 from commandor import Command, Commandor
 
@@ -40,6 +41,26 @@ class ServerStart(Command):
     """
     parent = Server
 
+    options = [
+        Option("-P", "--port",
+               metavar="int",
+               default=8891,
+               help="Port to run http server"),
+        Option("-r", "--reload",
+               action="store_true",
+               dest="reload",
+               default=False,
+               help="Auto realod source on changes"),
+        Option("-H", "--host",
+               metavar="str",
+               default="127.0.0.1",
+               help="Port for server"),
+        Option("-l", "--logging",
+               metavar="str",
+               default="none",
+               help="Log level")]
+
+
 
 class ServerStop(Command):
     """Stop given server
@@ -73,12 +94,35 @@ class ClusterInfo(Command):
     """
     parent = Cluster
 
+class RootLevel(Command):
+    """Root level command
+    """
+    commandor = CustomCommandor
+
+class Level1(Command):
+    """Level1 command
+    """
+    parent = RootLevel
+
+class Level2(Command):
+    """Level2 command
+    """
+    parent = Level1
+
+class Level3(Command):
+    """Level3
+    """
+    parent = Level2
+
+class Level4(Command):
+    """Level4
+    """
+    parent = Level3
 
 def main():
     """Main execution loop
     """
 
-    import ipdb; ipdb.set_trace()
     parser = OptionParser(
         usage="%prog [options] <commands>",
         add_help_option=False)
